@@ -6,7 +6,7 @@ from . import BaseCoder
 
 class JsonCoder(BaseCoder):
     def encode(self, data):
-        return json.dumps(data)
+        return json.dumps(data, separators=(',',':')) # compact form
 
     def decode(self, data):
         return json.loads(data)
\ No newline at end of file
